Plotting
========

Utility
-------

.. python-apigen-group:: plot-utility

Time-domain
-----------

.. python-apigen-group:: plot-time-domain

Frequency-domain
----------------

.. python-apigen-group:: plot-frequency-domain

Spectral estimation
-------------------

.. python-apigen-group:: plot-spectral-estimation

Modulation
----------

.. python-apigen-group:: plot-modulation

Detection
---------

.. python-apigen-group:: plot-detection

Filter analysis
---------------

.. python-apigen-group:: plot-filter
